@@ -14,12 +14,7 @@ class YoutubePlugin : public Purpose::PluginBase
 {
     Q_OBJECT
 public:
-    YoutubePlugin(QObject *parent, const QVariantList &args)
-        : Purpose::PluginBase(parent)
-    {
-        Q_UNUSED(args);
-    }
-
+    using PluginBase::PluginBase;
     Purpose::Job *createJob() const override
     {
         return new YoutubeJobComposite;
